Apyrat: An Aparat video downloader
===================================

.. image:: https://img.shields.io/static/v1?logo=github&label=Git&style=flat-square&color=brightgreen&message=Source%20code
  :alt: Source code
  :target: https://github.com/CodeWithEmad/apyrat

.. image:: https://img.shields.io/pypi/v/apyrat?logo=python&logoColor=white
  :alt: PyPI releases
  :target: https://pypi.python.org/pypi/apyrat

.. image:: https://img.shields.io/github/license/CodeWithEmad/apyrat.svg?style=flat-square
  :alt: MIT License
  :target: https://opensource.org/license/mit/


Getting Started
---------------

you can install Apyrat from PyPi:

``$ pip install -U apyrat``

for example you want to download the video hosted `here <https://www.aparat.com/v/qur3I>`__. just run:

``$ apyrat https://www.aparat.com/v/qur3I``

you can also download playlists:

``$ apyrat https://www.aparat.com/playlist/448747``


Contributing
------------

Any contributions are welcome here! To learn how you can contribute, please check the `contributing doc <https://github.com/CodeWithEmad/apyrat/blob/master/CONTRIBUTING.rst>`__.

License
-------

This work is licensed under the terms of the `MIT <https://github.com/CodeWithEmad/apyrat/blob/master/LICENSE>`_.
